ledger.MovementsByVoucher (Movements) — amici1

# `ledger.MovementsByVoucher` (Movements)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.related.ForeignKey: voucher>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<django.db.models.fields.IntegerField: seqno>`

- `<django.db.models.fields.related.ForeignKey: account>`

- `<lino.core.fields.PriceField: amount>`

- `<django.db.models.fields.CharField: match>`

- `<django.db.models.fields.BooleanField: cleared>`

- `<django.db.models.fields.DateField: value_date>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- Create (submit_insert) : Create the record and open a detail window on it

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

Filter parameters

- `<django.db.models.fields.related.ForeignKey: year>`

- `<lino.core.choicelists.ChoiceListField: journal_group>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.core.fields.DummyField object at 0x7fc81dfdcf98>`

- `<django.db.models.fields.related.ForeignKey: account>`

- `<django.db.models.fields.related.ForeignKey: journal>`

- `<lino.core.choicelists.ChoiceListField: cleared>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: start_period>`

- `<django.db.models.fields.related.ForeignKey: end_period>`

## Filter parameters